@@ -1,5 +1,8 @@
 /*
-  Copyright (C) 1994-2020 Free Software Foundation, Inc.
+  Copyright (C) 1994, 1995, 1996, 1997, 1998, 1999, 2000, 2001, 2002,
+  2003, 2004, 2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013,
+  2014, 2015, 2016, 2017, 2018, 2019, 2020, 2021 Free Software
+  Foundation, Inc.
 
   This file is part of GNU Inetutils.
 
@@ -88,7 +91,7 @@ extern void user (const char *);
 extern char *sgetsave (const char *);
 
 /* Exported from ftpd.c.  */
-jmp_buf errcatch;
+extern jmp_buf errcatch;
 extern struct sockaddr_storage data_dest;
 extern socklen_t data_dest_len;
 extern struct sockaddr_storage his_addr;
