@@ -1,5 +1,8 @@
 /*
-  Copyright (C) 1995-2020 Free Software Foundation, Inc.
+  Copyright (C) 1995, 1996, 1997, 1998, 1999, 2000, 2001, 2002, 2003,
+  2004, 2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014,
+  2015, 2016, 2017, 2018, 2019, 2020, 2021 Free Software Foundation,
+  Inc.
 
   This file is part of GNU Inetutils.
 
@@ -730,7 +733,7 @@ printsub (char direction, unsigned char *pointer, int length)
 	      {
 		char tbuf[64];
 
-		sprintf (tbuf, "%s%s%s%s%s",
+		snprintf (tbuf, sizeof (tbuf), "%s%s%s%s%s",
 			 pointer[2] & MODE_EDIT ? "|EDIT" : "",
 			 pointer[2] & MODE_TRAPSIG ? "|TRAPSIG" : "",
 			 pointer[2] & MODE_SOFT_TAB ? "|SOFT_TAB" : "",
