@@ -1,6 +1,7 @@
 #!/bin/sh
 
-# Copyright (C) 2009-2020 Free Software Foundation, Inc.
+# Copyright (C) 2009, 2010, 2011, 2012, 2013, 2014, 2015, 2016, 2017,
+# 2018, 2019, 2020, 2021 Free Software Foundation, Inc.
 #
 # This file is part of GNU Inetutils.
 #
@@ -25,6 +26,16 @@
 
 . ./tools.sh
 
+PROTOCOLS=/etc/protocols
+if test ! -r $PROTOCOLS; then
+    cat <<-EOT >&2
+	This test requires the availability of "$PROTOCOLS",
+	a file which can not be found in the current system.
+	Therefore skipping this test.
+	EOT
+    exit 77
+fi
+
 TRACEROUTE=${TRACEROUTE:-../src/traceroute$EXEEXT}
 TARGET=${TARGET:-127.0.0.1}
 
@@ -38,7 +49,12 @@ if [ $VERBOSE ]; then
     $TRACEROUTE --version
 fi
 
-if [ `func_id_uid` != 0 ]; then
+if test "$TEST_IPV4" = "no"; then
+    echo >&2 "Disabled IPv4 testing.  Skipping test."
+    exit 77
+fi
+
+if test `func_id_uid` != 0; then
     echo "traceroute needs to run as root"
     exit 77
 fi
@@ -46,11 +62,13 @@ fi
 errno=0
 errno2=0
 
-$TRACEROUTE --type=udp $TARGET || errno=$?
-test $errno -eq 0 || echo "Failed at UDP tracing." >&2
+if test "$TEST_IPV4" != "no" && test -n "$TARGET"; then
+    $TRACEROUTE --type=udp $TARGET || errno=$?
+    test $errno -eq 0 || echo "Failed at UDP tracing." >&2
 
-$TRACEROUTE --type=icmp $TARGET || errno2=$?
-test $errno2 -eq 0 || echo "Failed at ICMP tracing." >&2
+    $TRACEROUTE --type=icmp $TARGET || errno2=$?
+    test $errno2 -eq 0 || echo "Failed at ICMP tracing." >&2
+fi
 
 test $errno -eq 0 || exit $errno
 
